package com.example.bondoyap.service

import android.content.Context
import android.content.SharedPreferences
import com.example.bondoyap.service.api.Constants.SHARED_PREFS_NAME
import com.example.bondoyap.ui.login.data.model.LoggedInUser
import com.squareup.moshi.Moshi
import com.squareup.moshi.JsonAdapter
import com.squareup.moshi.kotlin.reflect.KotlinJsonAdapterFactory

class SessionManager(context: Context) {

    private var prefs: SharedPreferences = context.getSharedPreferences(SHARED_PREFS_NAME,
        Context.MODE_PRIVATE)
    private val editor: SharedPreferences.Editor = prefs.edit()


    private val moshi: Moshi = Moshi.Builder().add(KotlinJsonAdapterFactory()).build()
    private val userAdapter: JsonAdapter<LoggedInUser> = moshi.adapter(LoggedInUser::class.java)

    private fun getUser(): LoggedInUser? {
        val userJson = prefs.getString("loggedInUser", null)
        return userJson?.let {
            userAdapter.fromJson(it)
        }
    }

    fun saveExp(exp: Long){
        editor.putLong("exp", exp)
        editor.apply()
    }

    fun hasExp(): Boolean{
        return getExp().toInt() != -1
    }

    fun getExp(): Long {
        return prefs.getLong("exp", -1)
    }

    fun getToken(): String? {
        val user = getUser()
        return user?.let {
            user.token
        }
    }

    fun logout(){
        editor.clear()
        editor.apply()
    }
}