package com.example.bondoyap.service.jwt

import android.app.Service
import android.content.Context
import android.content.Intent
import android.os.Handler
import android.os.IBinder
import android.util.Log
import android.widget.Toast
import com.example.bondoyap.service.SessionManager
import com.example.bondoyap.service.api.ApiClient
import com.example.bondoyap.service.api.data.TokenResponse
import com.example.bondoyap.ui.login.LoginActivity
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response


class JwtService : Service() {

    private lateinit var handler : Handler

    private lateinit var session: SessionManager

    private val task = object : Runnable {
        override fun run() {
            Log.d("JwtService", "Current Time: ${System.currentTimeMillis()}")

            session =  SessionManager(applicationContext)
            val token = session.getToken()

            if (token != null) {
                verifyJwt(applicationContext, token)
            }
            // 5 second
            handler.postDelayed(this, 5000)
        }
    }

    private lateinit var apiClient: ApiClient

    override fun onCreate() {
        super.onCreate()
        handler = Handler(mainLooper)
    }

    override fun onStartCommand(intent: Intent?, flags: Int, startId: Int): Int {
        handler.post(task)
        return START_STICKY
    }

    override fun onBind(intent: Intent): IBinder? {
        return null
    }

    override fun onDestroy() {
        super.onDestroy()
        handler.removeCallbacks(task)
    }

    fun verifyJwt(context: Context, token: String){
        if (session.hasExp()) {
            checkJwt(session.getExp())
            return
        }
        apiClient = ApiClient()
        apiClient.getApiService(context).verifyToken(token).enqueue(object: Callback<TokenResponse>{
            override fun onFailure(call: Call<TokenResponse>, t: Throwable) {
                Log.d("JwtService", "Error Failure")
            }

            override fun onResponse(call: Call<TokenResponse>, response: Response<TokenResponse>) {
                Log.d("JwtService", "Getting Response")

                val tokenResponse = response.body()

                if (tokenResponse != null){
                    Log.d("JwtService", "Updating Exp")

                    session.saveExp(tokenResponse.exp)
                    checkJwt(tokenResponse.exp)
                } else {
                    Log.d("JwtService", "Error response")
                    Log.d("JwtService", "Error expired?")
                    handleExpired()
                }

            }
        })
    }

    fun checkJwt(exp: Long) {
        val currentTimestamp = System.currentTimeMillis() / 1000

        Log.d("JwtService", "exp : ${exp}")
        Log.d("JwtService", "currentTime : ${currentTimestamp}")

        if (currentTimestamp >= exp) {
            Log.d("JwtService", "JWT is expired")
            handleExpired()
        } else {
            Log.d("JwtService", "JWT is still valid")
        }
    }

    fun handleExpired(){
        session.logout()
        Toast.makeText(applicationContext, "Session Expired! \n Logging out ...", Toast.LENGTH_LONG).show()

        val intent = Intent(applicationContext, LoginActivity::class.java)
        intent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
        startActivity(intent)
        stopSelf()
    }
}