package com.example.bondoyap.ui.login.data

import android.content.Context
import android.util.Log
import com.example.bondoyap.service.api.ApiClient
import com.example.bondoyap.service.api.data.LoginRequest
import com.example.bondoyap.ui.login.data.model.LoggedInUser
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.withContext
import java.io.IOException

/**
 * Class that handles authentication w/ login credentials and retrieves user information.
 */
class LoginDataSource(private val context: Context) {

    private lateinit var apiClient: ApiClient

    suspend fun login(email: String, password: String): Result<LoggedInUser> {
        return try {

            val token = postLogin(email, password)

            val parts = email.split("@")
            val nim = parts[0]

            val user = LoggedInUser(nim, email, token)

            Result.Success(user)
        } catch (e: Throwable) {
            Result.Error(IOException("Error logging in", e))
        }
    }

    private suspend fun postLogin(email: String, password: String):String {

        apiClient = ApiClient()
        val service = apiClient.getApiService(context)

        return withContext(Dispatchers.IO) {
            try {
                val loginRequest = LoginRequest(email, password)
                val response = service.login(loginRequest).execute()

                if (response.isSuccessful) {
                    val loginResponse = response.body()
                    loginResponse?.token ?: throw IOException("Token not received")
                } else {
                    Log.d("LoginDataSource", "${response.code()} ${response.message()}")
                    throw IOException("${response.code()} ${response.message()}")
                }
            } catch (e: Exception) {
                Log.d("LoginDataSource", "Login failed: ${e.message}")
                throw IOException("Login failed: ${e.message}")
            }
        }
    }
}