package com.example.bondoyap.ui.login.data

import com.example.bondoyap.ui.login.data.model.LoggedInUser
import android.content.Context
import android.content.SharedPreferences
import com.example.bondoyap.service.api.Constants.SHARED_PREFS_NAME
import com.squareup.moshi.JsonAdapter
import com.squareup.moshi.Moshi
import com.squareup.moshi.kotlin.reflect.KotlinJsonAdapterFactory

/**
 * Class that requests authentication and user information from the remote data source and
 * maintains an in-memory cache of login status and user credentials information.
 */

class LoginRepository(val dataSource: LoginDataSource, context: Context) {

    private val sharedPreferences: SharedPreferences = context.getSharedPreferences(SHARED_PREFS_NAME, Context.MODE_PRIVATE)
    private val editor: SharedPreferences.Editor = sharedPreferences.edit()

    private val moshi: Moshi = Moshi.Builder().add(KotlinJsonAdapterFactory()).build()
    private val userAdapter: JsonAdapter<LoggedInUser> = moshi.adapter(LoggedInUser::class.java)

    val isLoggedIn: Boolean
        get() = sharedPreferences.getBoolean("isLoggedIn", false)

    suspend fun login(email: String, password: String): Result<LoggedInUser> {
        val result = dataSource.login(email, password)

        if (result is Result.Success) {
            setLoggedInUser(result.data)
        }

        return result
    }

    fun logout(){
        editor.clear()
        editor.apply()
    }

    fun getUser(): LoggedInUser? {
        val userJson = sharedPreferences.getString("loggedInUser", null)
        return userJson?.let {
            userAdapter.fromJson(it)
        }
    }

    private fun setLoggedInUser(loggedInUser: LoggedInUser) {
        val userJson = userAdapter.toJson(loggedInUser)
        editor.putString("loggedInUser", userJson).apply()
        editor.putBoolean("isLoggedIn", true).apply()
        // If user credentials will be cached in local storage, it is recommended it be encrypted
        // @see https://developer.android.com/training/articles/keystore
    }
}