package com.example.bondoyap.ui.settings

import android.content.Intent
import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.Toast
import androidx.fragment.app.Fragment
import androidx.lifecycle.ViewModelProvider
import com.example.bondoyap.databinding.FragmentSettingsBinding
import com.example.bondoyap.ui.login.LoginActivity

class SettingsFragment : Fragment() {

    private var _binding: FragmentSettingsBinding? = null
    private val binding get() = _binding!!
    private lateinit var settingsViewModel: SettingsViewModel

    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        _binding = FragmentSettingsBinding.inflate(inflater, container, false)
        return binding.root
    }
    override fun onViewCreated(view: View, savedInstanceState: Bundle?) {
        super.onViewCreated(view, savedInstanceState)

        val factory = context?.let { SettingsViewModelFactory(it) }
        if (factory != null) {
            settingsViewModel = ViewModelProvider(this, factory)[SettingsViewModel::class.java]
        } else {
            throw IllegalStateException("Context is null. Cannot create SettingsViewModelFactory.")
        }
        val textView = binding.textSettings
        val logoutButton = binding.logoutButton
        val randomButton = binding.randomTransactions
        val saveButton = binding.saveTransactions
        val sendButton = binding.sendTransactions

        settingsViewModel.getUser()?.let { user ->
            val loggedInUserText = "Masuk dengan akun:\n ${user.email}"
            textView.text = loggedInUserText
        }
        val appContext = context?.applicationContext

        logoutButton.setOnClickListener {
            settingsViewModel.getUser()
            settingsViewModel.logout()
//            findNavController().navigate(R.id.navigation_login)

            val activity = requireActivity()
            val intent = Intent(activity, LoginActivity::class.java)
            Toast.makeText(appContext, "Logout Sukses!", Toast.LENGTH_SHORT).show()
            activity.startActivity(intent)
            activity.finish()
        }

        randomButton.setOnClickListener {
            Toast.makeText(appContext, "Membuat transaksi random ...", Toast.LENGTH_SHORT).show()
            //todo
        }

        saveButton.setOnClickListener{
            Toast.makeText(appContext, "Menyimpan transaksi...", Toast.LENGTH_SHORT).show()
            //todo
        }

        sendButton.setOnClickListener{
            Toast.makeText(appContext, "Mengirimkan transaksi ...", Toast.LENGTH_SHORT).show()
            //todo
        }

    }

    override fun onDestroyView() {
        super.onDestroyView()
        _binding = null
    }
}